package DOM::Tiny;

use strict;
use warnings;
use base qw(Mojo::DOM58);

our $VERSION = '0.005';

1;

=encoding utf8

=head1 NAME

DOM::Tiny - This is an empty subclass, you wanted Mojo::DOM58

=head1 IT'S DEAD, JIM.

Development continues under the name L<Mojo::DOM58>.

This is an empty subclass thereof to avoid defecating on existing users
from a great height, but you should still update your code.

=head1 AUTHOR

Dan Book <dbook@cpan.org>

Code and tests adapted from L<Mojo::DOM>, a lightweight DOM parser by the L<Mojolicious> team.

=head1 CONTRIBUTORS

=over

=item Matt S Trout (mst)

=back

=head1 COPYRIGHT AND LICENSE

Copyright (c) 2008-2015 Sebastian Riedel.

Copyright (c) 2015 L</"AUTHOR"> and L</"CONTRIBUTORS"> for adaptation to standalone format.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)

=head1 SEE ALSO

L<Mojo::DOM>, L<HTML::TreeBuilder>, L<XML::LibXML>, L<XML::Twig>, L<XML::Smart>

=for Pod::Coverage TO_JSON

=cut
